@@ -236,7 +236,7 @@ class OFTI(Sampler,):
             # compute sep/PA of generated orbits
             ra, dec, vc = orbitize.kepler.calc_orbit(
                 self.epochs[min_epoch], sma, ecc, inc, argp, lan, tau, plx, mtot, 
-                mass_for_Kamp=m1
+                tau_ref_epoch=0, mass_for_Kamp=m1, tau_warning=False
             )
             sep, pa = orbitize.system.radec2seppa(ra, dec) # sep[mas], PA[deg]
 
@@ -255,7 +255,12 @@ class OFTI(Sampler,):
             # perform scale-and-rotate
             sma *= sma_corr # [AU]
             lan += np.radians(lan_corr) # [rad]
-            lan = lan % (2*np.pi)
+            lan = (lan + 2 * np.pi) % (2 * np.pi)
+
+            if self.system.restrict_angle_ranges:
+                argp[lan >= np.pi] += np.pi
+                argp = argp % (2 * np.pi)
+                lan[lan >= np.pi] -= np.pi
 
             period_new = np.sqrt(
                 4*np.pi**2*(sma*u.AU)**3/(consts.G*(mtot*u.Msun))
@@ -266,6 +271,7 @@ class OFTI(Sampler,):
 
             # updates samples with new values of sma, pan, tau
             samples[ref_ind,:] = sma
+            samples[ref_ind + 3,:] = argp
             samples[ref_ind + 4,:] = lan
             samples[ref_ind + 5,:] = tau
 
@@ -293,7 +299,6 @@ class OFTI(Sampler,):
         errs = np.array([self.system.data_table['quant1_err'],
                          self.system.data_table['quant2_err']]).T
         lnp_scaled = lnp + np.sum(np.log(np.sqrt(2*np.pi*errs**2)))
-        # pdb.set_trace()
 
         # reject orbits with probability less than a uniform random number
         random_samples = np.log(np.random.random(len(lnp)))
@@ -640,21 +645,23 @@ class MCMC(Sampler):
                 ntemps=self.num_temps, threads=self.num_threads, logpargs=[self.priors, ]
             )
         else:
+            if self.num_threads != 1:
+                print('Setting num_threads=1. If you want parallel processing for emcee implemented in orbitize, let us know.')
+                self.num_threads = 1
+
             sampler = emcee.EnsembleSampler(
                 self.num_walkers, self.num_params, self._logl,
-                threads=self.num_threads, kwargs={'include_logp': True}
+                kwargs={'include_logp': True}
             )
+                
         
-        # we're using args because emcee < 3.0 has three return values whereas emcee > 3.0 has
-        # four. We can explicitly declare 4 variables instead of args in the future. 
-        for args in sampler.sample(self.curr_pos, iterations=burn_steps, thin=thin):
-            pass
+        for state in sampler.sample(self.curr_pos, iterations=burn_steps, thin=thin):
+            if self.use_pt:
+                self.curr_pos = state[0]
+            else:
+                self.curr_pos = state.coords
 
         sampler.reset()
-        try:
-            self.curr_pos = args[0]
-        except UnboundLocalError:  # 0 step burn-in (pos is not defined)
-            pass
         print('Burn in complete')
 
         nsteps = int(np.ceil(total_orbits / self.num_walkers))
@@ -662,17 +669,17 @@ class MCMC(Sampler):
         assert (nsteps > 0), 'Total_orbits must be greater than num_walkers.'
 
         i=0
-        # we're using args because emcee < 3.0 has three return values whereas emcee > 3.0 has
-        # four. We can explicitly declare 4 variables instead of args in the future. 
-        for args in sampler.sample(self.curr_pos, iterations=nsteps, thin=thin):
+        for state in sampler.sample(self.curr_pos, iterations=nsteps, thin=thin):
+            if self.use_pt:
+                self.curr_pos = state[0]
+            else:
+                self.curr_pos = state.coords
             i+=1
             # print progress statement
             if i % 5 == 0:
                 print(str(i)+'/'+str(nsteps)+' steps completed', end='\r')
         print('')
 
-        self.curr_pos = args[0] # note that args[0] is pos output
-
         # TODO: Need something here to pick out temperatures, just using lowest one for now
         self.chain = sampler.chain
 
@@ -701,7 +708,7 @@ class MCMC(Sampler):
 
         return sampler
 
-    def examine_chains(self, param_list=None, walker_list=None, n_walkers=None, step_range=None):
+    def examine_chains(self, param_list=None, walker_list=None, n_walkers=None, step_range=None, transparency = 1):
         """
         Plots position of walkers at each step from Results object. Returns list of figures, one per parameter
         Args:
@@ -714,6 +721,8 @@ class MCMC(Sampler):
                 If None (default), walkers selected as per `walker_list`
             step_range (array or tuple): Start and end values of step numbers to plot
                 If None (default), all the steps are plotted
+            transparency (int or float): Determines visibility of the plotted function
+                If 1 (default) results plot at 100% opacity
 
         Returns:
             List of ``matplotlib.pyplot.Figure`` objects:
@@ -754,12 +763,12 @@ class MCMC(Sampler):
         for pp in params_to_plot:
             fig, ax = plt.subplots()
             for ww in walkers_to_plot:
-                ax.plot(chn[ww, :, pp], 'k-')
+                ax.plot(chn[ww, :, pp], 'k-', alpha = transparency)
             ax.set_xlabel('Step')
             if step_range is not None:  # Limit range shown if step_range is set
                 ax.set_xlim(step_range)
             output_figs.append(fig)
-
+        
         # Return
         return output_figs
 
