@@ -60,6 +60,7 @@ class System(object):
         self.results = []
         self.fit_secondary_mass = fit_secondary_mass
         self.tau_ref_epoch = tau_ref_epoch
+        self.restrict_angle_ranges = restrict_angle_ranges
 
         #
         # Group the data in some useful ways
@@ -235,8 +236,13 @@ class System(object):
                 # mass of secondary bodies are in order from -1-num_bodies until -2 in order.
                 mass = params_arr[-1-self.num_secondary_bodies+(body_num-1)]
                 m0 = params_arr[-1]
-                mtot = m0 + mass
-                # TODO: include the masses of other bodies?
+                # For what mtot to use to calculate central potential, we should use the mass enclosed in a sphere with r <= distance of planet. 
+                # We need to select all planets with sma < this planet. 
+                all_smas = params_arr[0:6*self.num_secondary_bodies:6]
+                within_orbit = np.where(all_smas <= sma)
+                all_pl_masses = params_arr[-1-self.num_secondary_bodies:-1]
+                inside_masses = all_pl_masses[within_orbit]
+                mtot = np.sum(inside_masses) + m0
             else:
                 # if not fitting for secondary mass, then total mass must be stellar mass
                 mass = None
@@ -247,7 +253,7 @@ class System(object):
 
             raoff, decoff, vz_i = kepler.calc_orbit(
                 epochs, sma, ecc, inc, argp, lan, tau, plx, mtot,
-                mass_for_Kamp=m0, tau_ref_epoch=self.tau_ref_epoch
+                mass_for_Kamp=m0, tau_ref_epoch=self.tau_ref_epoch, tau_warning=False
             )
 
             # raoff, decoff, vz are scalers if the length of epochs is 1. 
@@ -261,7 +267,7 @@ class System(object):
 
             # vz_i is the ith companion radial velocity
             if self.fit_secondary_mass:
-                vz0 = vz_i*-(mass/m0)  # calculating stellar velocity due to ith companion
+                vz0 = vz_i*-(mass/mtot)  # calculating stellar velocity due to ith companion
                 total_rv0 = total_rv0 + vz0  # Adding stellar velocity and gamma
 
             # for the model points that correspond to this planet's orbit, add the model prediction
@@ -293,11 +299,11 @@ class System(object):
                     ## NOTE: we are only handling ra/dec and sep/pa right now
                     ## TOOD: integrate RV into this
                     if len(self.radec[other_body_num]) > 0:
-                        radec_perturb[self.radec[other_body_num], 0] += -(mass/m0) * raoff[self.radec[other_body_num]]
-                        radec_perturb[self.radec[other_body_num], 1] += -(mass/m0) * decoff[self.radec[other_body_num]] 
+                        radec_perturb[self.radec[other_body_num], 0] += -(mass/mtot) * raoff[self.radec[other_body_num]]
+                        radec_perturb[self.radec[other_body_num], 1] += -(mass/mtot) * decoff[self.radec[other_body_num]] 
                     if len(self.seppa[other_body_num]) > 0:
-                        radec_perturb[self.seppa[other_body_num], 0] += -(mass/m0) * raoff[self.seppa[other_body_num]]
-                        radec_perturb[self.seppa[other_body_num], 1] += -(mass/m0) * decoff[self.seppa[other_body_num]]
+                        radec_perturb[self.seppa[other_body_num], 0] += -(mass/mtot) * raoff[self.seppa[other_body_num]]
+                        radec_perturb[self.seppa[other_body_num], 1] += -(mass/mtot) * decoff[self.seppa[other_body_num]]
 
         if self.fit_secondary_mass:
             if len(total_rv0[self.rv[0]]) > 0:
